<template>
  <!-- 搜索 -->
  <ContentWrap>
    <el-form
      class="-mb-15px"
      :model="queryParams"
      ref="queryFormRef"
      :inline="true"
      label-width="85px"
    >
      <el-form-item label="预测项名称" prop="outputName">
        <el-input
          v-model="queryParams.outputName"
          placeholder="请输入名称"
          clearable
          @keyup.enter="handleQuery"
          class="!w-240px"
        />
      </el-form-item>
      <el-form-item label="统计方式" prop="pattern">
        <el-select v-model="queryParams.pattern" placeholder="请选择统计方式" clearable @keyup.enter="handleQuery" class="!w-240px">
          <el-option
            v-for="dict in getStrDictOptions(DICT_TYPE.INFLUENCE_FACTOR_PATTERN)"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button @click="handleQuery">
          <Icon icon="ep:search" class="mr-5px" />
          搜索
        </el-button>
        <el-button @click="resetQuery">
          <Icon icon="ep:refresh" class="mr-5px" />
          重置
        </el-button>
        <el-button
          type="primary"
          plain
          @click="openForm('create')"
          v-hasPermi="['pre:influence-factor:create']"
        >
          <Icon icon="ep:plus" class="mr-5px" />
          新增
        </el-button>
      </el-form-item>
    </el-form>
  </ContentWrap>

  <!-- 列表 -->
  <ContentWrap>
    <el-table v-loading="loading" :data="list">
      <el-table-column label="预测项名称" header-align="center" align="center" prop="outputName" fixed/>
      <el-table-column label="统计方式" align="center" prop="pattern">
        <template #default="scope">
          <dict-tag :type="DICT_TYPE.INFLUENCE_FACTOR_PATTERN" :value="scope.row.pattern" />
        </template>
      </el-table-column>
      <el-table-column label="是否启用" header-align="center" align="center" min-width="100" prop="isEnable" >
        <template #default="scope">
          <dict-tag :type="DICT_TYPE.COM_IS_INT" :value="scope.row.isEnable" />
        </template>
      </el-table-column>
      <el-table-column prop="createTime" align="center" label="创建时间" :formatter="dateFormatter"/>
      <el-table-column label="影响因素" type="expand" width="100px">
        <template #default="props">
          <el-table :data="props.row.influenceFactors">
            <el-table-column align="center" label="因素名称" prop="factorOutputName" />
            <el-table-column align="center" label="偏差值" prop="deviationValue" />
            <el-table-column prop="" label="操作" align="center">
              <template #default="scope">
                <el-button
                  @click="showResult(scope.row.id)"
                  type="text">
                  查看结果
                </el-button>
              </template>
            </el-table-column>
          </el-table>
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" fixed="right">
        <template #default="scope">
          <el-button
            link
            type="primary"
            @click="openForm('update', scope.row.id)"
            v-hasPermi="['pre:influence-factor:update']"
          >
            编辑
          </el-button>
          <el-button
            link
            type="danger"
            @click="handleDelete(scope.row.id)"
            v-hasPermi="['pre:influence-factor:delete']"
          >
            删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>
    <!-- 分页 -->
    <Pagination
      :total="total"
      v-model:page="queryParams.pageNo"
      v-model:limit="queryParams.pageSize"
      @pagination="getList"
    />
  </ContentWrap>

  <!-- 表单弹窗：添加/修改 -->
  <MmPredictInfluenceFactorForm ref="formRef" @success="getList" />
  <!-- 历史结果 -->
  <MmPredictInfluenceFactorResult ref="resultRef" />

</template>
<script lang="ts" setup>
import MmPredictInfluenceFactorForm from './MmPredictInfluenceFactorForm.vue'
import MmPredictInfluenceFactorResult from './MmPredictInfluenceFactorResult.vue'
import * as influenceFactorApi from '@/api/model/pre/influenceFactor/influenceFactorApi'
import {dateFormatter} from '@/utils/formatTime'
import {DICT_TYPE, getIntDictOptions,getStrDictOptions} from "@/utils/dict";

defineOptions({name: 'influenceFactor'})

  const message = useMessage() // 消息弹窗
  const {t} = useI18n() // 国际化

  const loading = ref(true) // 列表的加载中
  const total = ref(0) // 列表的总页数
  const list = ref([]) // 列表的数据
  const queryParams = reactive({
    pageNo: 1,
    pageSize: 10,
    outputName: undefined,
    pattern: undefined,
  })
  const queryFormRef = ref() // 搜索的表单

  /** 查询列表 */
  const getList = async () => {
    loading.value = true
    try {
      const page = await influenceFactorApi.getPage(queryParams)
      list.value = page.list
      total.value = page.total
    } finally {
      loading.value = false
    }
  }

  /** 搜索按钮操作 */
  const handleQuery = () => {
    queryParams.pageNo = 1
    getList()
  }

  /** 重置按钮操作 */
  const resetQuery = () => {
    queryFormRef.value.resetFields()
    handleQuery()
  }

  /** 添加/修改操作 */
  const formRef = ref()
  const openForm = (type: string, id?: number) => {
    formRef.value.open(type, id)
  }

  /** 删除按钮操作 */
  const handleDelete = async (id: number) => {
    try {
      // 删除的二次确认
      await message.delConfirm()
      // 发起删除
      await influenceFactorApi.deleteConfig(id)
      message.success(t('common.delSuccess'))
      // 刷新列表
      await getList()
    } catch {
    }
  }
  /** 展示影响结果 */
  const resultRef = ref()
  const showResult = (id) => {
    resultRef.value.open(id)
  }

  /** 初始化 **/
  onMounted(async () => {
    await getList()
  })
</script>
